@@ -34,7 +34,7 @@ class FitnessEvaluator(AbstractFitnessEvaluator):
         disabled=to_approximate,
         estimator=estimator,
         controller=controller,
-        debug=True,
+        controller_debug=True,
     )
     def fitness(self, design_point: List[int]) -> List[float]:
         return list(
